@@ -51,7 +51,7 @@ class RetrieveAsLinksCommon:
 
 
 class RetrieveHolder(RetrieveAsLinksCommon):
-    def __init__(self, stub, feature_set, start_date_time, end_date_time):
+    def __init__(self, stub, feature_set, start_date_time, end_date_time, ingest_id):
         self._stub = stub
         self._thread_pool = ThreadPoolExecutor(5)
         self._feature_set = feature_set
@@ -59,6 +59,7 @@ class RetrieveHolder(RetrieveAsLinksCommon):
         self._end_date_time = end_date_time
         self._retrieve_as_spark_response = None
         self._job_id = None
+        self._ingest_id = ingest_id
 
     def _start_retrieve_links_job(self):
         request = self._create_retrieve_request()
@@ -94,6 +95,7 @@ class RetrieveHolder(RetrieveAsLinksCommon):
         from pyspark.sql.functions import (
             col,
             from_utc_timestamp,
+            lit,
             to_timestamp,
             unix_timestamp,
         )
@@ -110,8 +112,10 @@ class RetrieveHolder(RetrieveAsLinksCommon):
         start_timestamp = retrieve_scope.start_date_time.seconds
         end_timestamp = retrieve_scope.end_date_time.seconds
         timestamp_col = "timestamp_" + str(round(time.time() * 1000))
-        if self._feature_set.time_travel_column:
-            return (
+        if self._ingest_id:
+            output_df = df.filter(col("ingest_id") == lit(self._ingest_id))
+        elif self._feature_set.time_travel_column:
+            output_df = (
                 df.withColumn(
                     timestamp_col,
                     unix_timestamp(
@@ -126,14 +130,12 @@ class RetrieveHolder(RetrieveAsLinksCommon):
                 )
                 .filter(col(timestamp_col) <= end_timestamp)
                 .filter(col(timestamp_col) >= start_timestamp)
-                .drop(timestamp_col)
             )
         else:
-            return (
-                df.filter(col("time_travel_column_auto_generated") <= end_timestamp)
-                .filter(col("time_travel_column_auto_generated") >= start_timestamp)
-                .drop("time_travel_column_auto_generated")
-            )
+            output_df = df.filter(
+                col("time_travel_column_auto_generated") <= end_timestamp
+            ).filter(col("time_travel_column_auto_generated") >= start_timestamp)
+        return output_df.drop("ingest_id")
 
     def _create_retrieve_request(self):
         request = pb.RetrieveRequest()
@@ -142,6 +144,7 @@ class RetrieveHolder(RetrieveAsLinksCommon):
             request.start_date_time = self._start_date_time
         if self._end_date_time is not None:
             request.end_date_time = self._end_date_time
+        request.ingest_id = self._ingest_id
         return request
 
 
